OMERO.py
========

Introduction
------------

OMERO.py provides Python bindings to the OMERO.blitz server
as well as a pluggable command-line interface.

Dependencies
------------

Direct dependencies of OMERO.py are:

- `ZeroC IcePy`_

Installation
------------

See: `OMERO`_ documentation

Usage
-----

See: `OMERO`_ documentation

Contributing
------------

See: `OMERO`_ documentation

Running tests
-------------

Unit tests are located under the `test` directory and can be run with pytest.

Integration tests
^^^^^^^^^^^^^^^^^

Integration tests are stored in the main repository (ome/openmicroscopy) and depend on the
OMERO integration testing framework. Reading about `Running and writing tests`_ in the `OMERO`_ documentation
is essential.

License
-------

OMERO.py is released under the GPL v2.

Copyright
---------

2009-2019, The Open Microscopy Environment, Glencoe Software, Inc.

.. _ZeroC IcePy: https://zeroc.com/
.. _OMERO: https://www.openmicroscopy.org/omero
.. _Running and writing tests: https://docs.openmicroscopy.org/latest/omero/developers/testing.html
